.TH DTOS 1L "01 July 2005"
.\"======================================================================
.SH "NAME"
dtos \- convert Fortran program from double-precision to single-precision
.\"======================================================================
.SH "SYNOPSIS"
.B dtos
.RB [ \-\^\-? ]
.RB [ \-\^\-author ]
.RB [ \-\^\-copyright ]
.RB [ \-\^\-help ]
.RB [ \-\^\-version ]
.if n .ti +5n
< infile >outfile
.PP
.B dtos
copies its standard input to standard output,
converting Fortran double-precision constants,
built-in functions, and type declarations to
single precision.
.PP
Floating-point FORMAT specifications are left
intact; on some ancient systems, they may require
modifications.  They do
.I not
under the rules of Fortran 77.
.PP
Leading tabs are correctly interpreted according
to common extended Fortran rules.
.PP
.B dtos
recognizes all of the standard Fortran 77
single- and double-precision functions,
as well as the pair
.B "rand/drand"
(UNIX pseudo-random number generators), and
the pair
.B "r1mach/d1mach"
from the PORT library framework.
.PP
.BR dtos 's
other purpose is to demonstrate a modest
.BR lex (1)
program.
.\"======================================================================
.SH OPTIONS
Options can be prefixed with either one or two hyphens, and
can be abbreviated to any unique prefix.  Thus,
.BR \-v ,
.BR \-ver ,
and
.B \-\^\-version
are equivalent.
.PP
All options in this program are diagnostic, and suppress
processing of the input stream.  Execution terminates with a
success return code after processing one or more options,
but unrecognized options cause immediate termination with a
failure return code.
.\" --------------------------------------------------------
.TP \w'\fB\-\^\-copyright\fP'u+3n
.B \-\^\-?
Same as
.BR \-\^\-help .
.\" --------------------------------------------------------
.TP
.B \-\^\-author
Display a brief author credit on
.IR stdout .
.\" --------------------------------------------------------
.TP
.B \-\^\-copyright
Display copyright and license information on
.IR stdout .
.\" --------------------------------------------------------
.TP
.B \-\^\-help
Display a brief help message on
.IR stdout ,
giving a usage description.
.\" --------------------------------------------------------
.TP
.B \-\^\-version
Display the program version number and release date on
.IR stdout .
.\"======================================================================
.SH "BUGS"
Undeclared variables are not type-converted.  To find 
such instances, use the Extended PFORT Verifier, 
.BR pfort (1),
or the Fortran checker,
.BR ftnchek (1).
Some UNIX Fortran compilers have a compile-time
option, usually called
.IR \-u ,
to flag undeclared variables.
.PP
Text beyond column 72 is discarded when
lines are collected into Fortran statements.
.PP
.B dtos
does not handle embedded ASCII tab characters
correctly when long lines are to be broken.  A
Fortran-sensitive detabbing utility should be
applied first if the input file possibly contains
embedded tabs.  Note that
.BR expand (1)
.I cannot
be used to do this job correctly!
.PP
Mixed-precision code may not be converted correctly.
For example, 
.B "DBLE(FLOAT(N))"
will become
.BR "SNGL(FLOAT(N))" ,
which is syntactically incorrect.
.PP
Functions and variables of type 
.B COMPLEX
are not converted, because Fortran 77 does not
define a double precision complex type.  Complex
constants will be converted, however, since their
real and imaginary parts look like normal
floating-point values.
.\"======================================================================
.SH "SEE ALSO"
.BR ftnchek (1),
.BR lex (1),
.BR pfort (1),
.BR stod (1).
.\"======================================================================
.SH "AUTHOR"
.nf
Nelson H. F. Beebe
Department of Mathematics
University of Utah
Salt Lake City, UT 84112
Tel: +1 801 581 5254
FAX: +1 801 581 4148
Email: \fCbeebe@math.utah.edu\fP, \fCbeebe@acm.org\fP, \fCbeebe@computer.org\fP
.fi
.\"==============================[The End]==============================
